library(readr)
vaxdata <- read_delim("directory/model_Eng.csv", 
                      ";", escape_double = FALSE, trim_ws = TRUE)
View(vaxdata)

attach(vaxdata)

library(lavaan)

#model

mod1 <- '
#covariances
Suscep ~~ Sever

#paths
Suscep ~ a*Eng
Sever ~ b*Eng
Vaxatt ~ c*Eng
Vaxwill ~ d*Suscep + e*Vaxatt + f*Sever + g*Eng

#indirect effects
ad := a*d
bf := b*f
ce := c*e

#total effect
TotEng := ad + bf + ce + g
'

fit_mod1 <- sem(mod1, data=vaxdata, estimator='MLM', meanstructure=T)

summary(fit_mod1,standardized=TRUE, rsquare=TRUE, ci=TRUE)

fitmeasures(fit_mod1, c("cfi", "rmsea", "rmsea.ci.lower", "rmsea.ci.upper",
                        "srmr"))


### testing for invariance

## gender
#configural

mod1_inv <- '
#covariances
Suscep ~~ Sever

#paths
Suscep ~ Eng
Sever ~ Eng
Vaxatt ~ Eng
Vaxwill ~ Suscep + Vaxatt + Sever + Eng
'

fit_gen_conf <- sem(mod1_inv, 
                    data=vaxdata, 
                    estimator='MLM', 
                    meanstructure=T,
                    group = "Gender")

summary(fit_gen_conf,standardized=TRUE, rsquare=TRUE, ci=TRUE)

fitmeasures(fit_gen_conf, c("cfi", "rmsea", "rmsea.ci.lower", "rmsea.ci.upper",
                        "srmr"))

# weak

mod1_inv2 <- '
#covariances
Suscep ~~ c(z,z)*Sever

#paths
Suscep ~ Eng
Sever ~ Eng
Vaxatt ~ Eng
Vaxwill ~ Suscep + Vaxatt + Sever + Eng
'

fit_gen_weak <- sem(mod1_inv2, 
                    data=vaxdata, 
                    estimator='MLM', 
                    meanstructure=T,
                    group = "Gender",
                    group.equal = "regressions")

summary(fit_gen_weak,standardized=TRUE, rsquare=TRUE, ci=TRUE)

fitmeasures(fit_gen_weak, c("cfi", "rmsea", "rmsea.ci.lower", "rmsea.ci.upper",
                            "srmr"))

anova(fit_gen_conf, fit_gen_weak)


## age group
#configural

mod1_age <- '
#covariances
Suscep ~~ Sever

#paths
Suscep ~ c(a1,a2,a3)*Eng
Sever ~ c(b1,b2,b3)*Eng
Vaxatt ~ c(c1,c2,c3)*Eng
Vaxwill ~ c(d1,d2,d3)*Suscep + c(e1,e2,e3)*Vaxatt + c(f1,f2,f3)*Sever + c(g1,g2,g3)*Eng

#indirect effects group 1
ad1 := a1*d1
bf1 := b1*f1
ce1 := c1*e1

#total effect group 1
TotEng1 := ad1 + bf1 + ce1 + g1

#indirect effects group 2
ad2 := a2*d2
bf2 := b2*f2
ce2 := c2*e2

#total effect group 2
TotEng2 := ad2 + bf2 + ce2 + g2

#indirect effects group 3
ad3 := a3*d3
bf3 := b3*f3
ce3 := c3*e3

#total effect group 3
TotEng3 := ad3 + bf3 + ce3 + g3

'

fit_age_conf <- sem(mod1_age, 
                    data=vaxdata, 
                    estimator='MLM', 
                    meanstructure=T,
                    group = "Agegroup3")

summary(fit_age_conf,standardized=TRUE, rsquare=TRUE, ci=TRUE)

fitmeasures(fit_age_conf, c("cfi", "rmsea", "rmsea.ci.lower", "rmsea.ci.upper",
                            "srmr"))

#weak

mod1b_inv2 <- '
#covariances
Suscep ~~ c(z,z,z)*Sever

paths
Suscep ~ Eng
Sever ~ Eng
Vaxatt ~ Eng
Vaxwill ~ Suscep + Vaxatt + Sever + Eng
'

fit_age_weak <- sem(mod1b_inv2, 
                    data=vaxdata, 
                    estimator='MLM', 
                    meanstructure=T,
                    group = "Agegroup3",
                    group.equal = "regressions")

summary(fit_age_weak,standardized=TRUE, rsquare=TRUE, ci=TRUE)

fitmeasures(fit_age_weak, c("cfi", "rmsea", "rmsea.ci.lower", "rmsea.ci.upper",
                            "srmr"))

anova(fit_age_conf, fit_age_weak)

#weak partial

mod1_age_weakp <- '
#covariances
Suscep ~~ c(z,z,z)*Sever

#paths
Suscep ~ Eng
Sever ~ Eng
Vaxatt ~ Eng
Vaxwill ~ c(d1, d1, d2)*Suscep + Vaxatt + Sever + Eng
'

fit_age_weakp <- sem(mod1_age_weakp, 
                    data=vaxdata, 
                    estimator='MLM', 
                    meanstructure=T,
                    group = "Agegroup3",
                    group.equal="regressions")

summary(fit_age_weakp,standardized=TRUE, rsquare=TRUE, ci=TRUE)

fitmeasures(fit_age_weakp, c("cfi", "rmsea", "rmsea.ci.lower", "rmsea.ci.upper",
                            "srmr"))

anova(fit_age_conf, fit_age_weakp)
